import request from '@/request';
import { OAuth2ClientVO, OAuth2TokenPageReqVO, OAuth2TokenVO, OAuth2ClientPageReqVO, PageData } from '@/models';

const BASE_TOKEN_URL = '/admin-api/system/oauth2-token';
const BASE_CLIENT_URL = '/admin-api/system/oauth2-client';

export default {
    // 查询 token列表
    getAccessTokenPageApi: (params: OAuth2TokenPageReqVO) => {
        return request.get<PageData<OAuth2TokenVO>>(`${BASE_TOKEN_URL}/page`, {params})
    },

    // 删除 token
    deleteAccessTokenApi: (accessToken: number) => {
        return request.delete(`${BASE_TOKEN_URL}/delete?accessToken=${accessToken}`)
    },

    // 查询 OAuth2列表
    getOAuth2ClientPageApi: (params: OAuth2ClientPageReqVO) => {
        return request.get<PageData<OAuth2ClientVO>>(`${BASE_CLIENT_URL}/page`, {params})
    },

    // 查询 OAuth2详情
    getOAuth2ClientApi: (id: number) => {
        return request.get<OAuth2ClientVO>(`${BASE_CLIENT_URL}/get?id=${id}`)
    },

    // 新增 OAuth2
    createOAuth2ClientApi: (data: OAuth2ClientVO) => {
        return request.post(`${BASE_CLIENT_URL}/create`, data)
    },

    // 修改 OAuth2
    updateOAuth2ClientApi: (data: OAuth2ClientVO) => {
        return request.put(`${BASE_CLIENT_URL}/update`, data)
    },

    // 删除 OAuth2
    deleteOAuth2ClientApi: (id: number) => {
        return request.delete(`${BASE_CLIENT_URL}/delete?id=${id}`)
    },

};

